"""
Toyoura Sand (Drained)
======================

Drained triaxial tests on Toyoura sand with DEM [^1].

[^1]: Gu, X., Huang, M., & Qian, J. (2014). DEM investigation on the evolution of microstructure in granular soils under
      shearing. Granular Matter, 16(1), 91–106. https://doi.org/10.1007/s10035-013-0467-z
"""

import pandas as pd

from micromechanical.cli.plot import PlotCLI, PlotConfig

config: PlotConfig = PlotCLI.loadConfig("../../calibrations/micromechanical-plots.yaml")

plot_name = "Gu2014-drained-CH-SANISAND-two-column"
plot_config = config.plots[plot_name]

# %%
# Parameters
# ----------

pd.DataFrame(
    {
        key.replace("micromechanical.calibrationkey:FabricCoefficientKey(", "").replace(")", ""): value
        for key, value in plot_config.calibration.read(config.root).parameters.items()
    },
    index=["Gu2014-drained"],
)

# %%
# Figures
# -------

plot_config.plot(plot_name, grids=config.grids, save=False, overwrite=False, exclude_figures=["macroscopic-anisotropy"])
